summaryrefslogtreecommitdiffstats
path: root/src/common/nokde/nokde_kcmdlineargs.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/common/nokde/nokde_kcmdlineargs.h')
-rw-r--r--src/common/nokde/nokde_kcmdlineargs.h60
1 files changed, 30 insertions, 30 deletions
diff --git a/src/common/nokde/nokde_kcmdlineargs.h b/src/common/nokde/nokde_kcmdlineargs.h
index 8b79b62..8808d94 100644
--- a/src/common/nokde/nokde_kcmdlineargs.h
+++ b/src/common/nokde/nokde_kcmdlineargs.h
@@ -24,20 +24,20 @@
#include "nokde_klocale.h"
#include "nokde_kurl.h"
-# if QT_VERSION<0x040000
-# include <qptrlist.h>
-# include <qvaluelist.h>
+# if [[[TQT_VERSION IS DEPRECATED]]]<0x040000
+# include <tqptrlist.h>
+# include <tqvaluelist.h>
#else
-# include <Qt3Support/Q3CString>
-# define QCString Q3CString
-# include <Qt3Support/Q3PtrList>
-# define QPtrList Q3PtrList
-# include <Qt3Support/Q3ValueList>
-# define QValueList Q3ValueList
+# include <TQt3Support/Q3CString>
+# define TQCString Q3CString
+# include <TQt3Support/Q3PtrList>
+# define TQPtrList Q3PtrList
+# include <TQt3Support/Q3ValueList>
+# define TQValueList Q3ValueList
#endif
-# include <qstring.h>
+# include <tqstring.h>
-typedef QValueList<QCString> QCStringList;
+typedef TQValueList<TQCString> QCStringList;
/**
* @short Structure that holds command line options.
@@ -90,7 +90,7 @@ class KCmdLineArgsPrivate;
* @short A class for command-line argument handling.
*
* KCmdLineArgs provides simple access to the command-line arguments
* for an application. It takes into account Qt-specific options,
* KDE-specific options and application specific options.
*
* This class is used in %main() via the static method
@@ -129,13 +129,13 @@ class KCmdLineArgsPrivate;
* ....
*
* // An option which takes an additional argument
- * QCString anotherOptionArg = args->getOption("another-option");
+ * TQCString anotherOptionArg = args->getOption("another-option");
*
* // Arguments (e.g. files to open)
* for(int i = 0; i < args->count(); i++) // Counting start at 0!
* {
* // don't forget to convert to Unicode!
- * openFile( QFile::decodeName( args->arg(i)));
+ * openFile( TQFile::decodeName( args->arg(i)));
* // Or more convenient:
* // openURL( args->url(i));
*
@@ -234,7 +234,7 @@ class KDECORE_EXPORT KCmdLineArgs
{
friend class KApplication;
friend class KUniqueApplication;
- friend class QPtrList<KCmdLineArgs>;
+ friend class TQPtrList<KCmdLineArgs>;
public:
// Static functions:
@@ -253,7 +253,7 @@ public:
* @param _description A short description of what your application is about.
* @param _version A version.
* @param noKApp Set this true to not add commandline options for
- * QApplication / KApplication
+ * TQApplication / KApplication
*
* @since 3.2
*/
@@ -281,7 +281,7 @@ public:
* @param _argv As passed to @p main(...).
* @param about A KAboutData object describing your program.
* @param noKApp Set this true to not add commandline options for
- * QApplication / KApplication
+ * TQApplication / KApplication
*/
static void init(int _argc, char **_argv,
const KAboutData *about, bool noKApp = false);
@@ -389,7 +389,7 @@ public:
* where the user started a second instance.
* @return the current working directory
**/
- static QString cwd();
+ static TQString cwd();
/**
* Get the appname according to argv[0].
@@ -410,7 +410,7 @@ public:
* Print an error to stderr and the usage help to stdout and exit.
* @param error the error to print
**/
- static void usage(const QString &error);
+ static void usage(const TQString &error);
/**
* Enable i18n to be able to print a translated error message.
@@ -441,7 +441,7 @@ public:
* If the option was present more than the value of the
* last occurrence is used.
*/
- QCString getOption(const char *option) const;
+ TQCString getOption(const char *option) const;
/**
* Read out all occurrences of a string option.
@@ -543,7 +543,7 @@ public:
/**
* Load arguments from a stream.
*/
- static void loadAppArgs( QDataStream &);
+ static void loadAppArgs( TQDataStream &);
/**
* Add standard option --tempfile
@@ -582,7 +582,7 @@ private:
*
* Checks what to do with a single option
*/
- static void findOption(const char *_opt, QCString opt, int &i, bool enabled, bool &moreOptions);
+ static void findOption(const char *_opt, TQCString opt, int &i, bool enabled, bool &moreOptions);
/**
* @internal
@@ -619,23 +619,23 @@ private:
/**
* @internal for KUniqueApplication only:
*
* Save all but the Qt and KDE arguments to a stream.
*/
- static void saveAppArgs( QDataStream &);
+ static void saveAppArgs( TQDataStream &);
/**
* @internal
*
* Set a boolean option
*/
- void setOption(const QCString &option, bool enabled);
+ void setOption(const TQCString &option, bool enabled);
/**
* @internal
*
* Set a string option
*/
- void setOption(const QCString &option, const char *value);
+ void setOption(const TQCString &option, const char *value);
/**
* @internal
@@ -649,14 +649,14 @@ private:
*
* Save to a stream.
*/
- void save( QDataStream &) const;
+ void save( TQDataStream &) const;
/**
* @internal
*
* Restore from a stream.
*/
- void load( QDataStream &);
+ void load( TQDataStream &);
/**
* @internal for KApplication only
@@ -675,14 +675,14 @@ private:
*/
static void initIgnore(int _argc, char **_argv, const char *_appname);
- static void printQ(const QString &msg);
+ static void printQ(const TQString &msg);
const KCmdLineOptions *options;
const char *name;
const char *id;
KCmdLineParsedOptions *parsedOptionList;
KCmdLineParsedArgs *parsedArgList;
- bool isQt;
+ bool isTQt;
static KCmdLineArgsList *argsList; // All options.
static const KAboutData *about;
@@ -90,7 +90,7 @@ class KCmdLineArgsPrivate;
*
* KCmdLineArgs provides simple access to the command-line arguments
- * for an application. It takes into account Qt-specific options,
+ * for an application. It takes into account TQt-specific options,
* KDE-specific options and application specific options.
*
@@ -619,23 +619,23 @@ private:
* @internal for KUniqueApplication only:
*
- * Save all but the Qt and KDE arguments to a stream.
+ * Save all but the TQt and KDE arguments to a stream.
*/